package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcSafeMapper;
import com.ruoyi.oa.domain.CmcSafe;
import com.ruoyi.oa.service.ICmcSafeService;

/**
 * cmc安全交底Service业务层处理
 * 
 * @author cmc
 * @date 2024-04-03
 */
@Service
public class CmcSafeServiceImpl implements ICmcSafeService 
{
    @Autowired
    private CmcSafeMapper cmcSafeMapper;

    /**
     * 查询cmc安全交底
     * 
     * @param safeId cmc安全交底主键
     * @return cmc安全交底
     */
    @Override
    public CmcSafe selectCmcSafeBySafeId(String safeId)
    {
        return cmcSafeMapper.selectCmcSafeBySafeId(safeId);
    }

    /**
     * 查询cmc安全交底列表
     * 
     * @param cmcSafe cmc安全交底
     * @return cmc安全交底
     */
    @Override
    public List<CmcSafe> selectCmcSafeList(CmcSafe cmcSafe)
    {
        return cmcSafeMapper.selectCmcSafeList(cmcSafe);
    }

    /**
     * 新增cmc安全交底
     * 
     * @param cmcSafe cmc安全交底
     * @return 结果
     */
    @Override
    public int insertCmcSafe(CmcSafe cmcSafe)
    {
        return cmcSafeMapper.insertCmcSafe(cmcSafe);
    }

    /**
     * 修改cmc安全交底
     * 
     * @param cmcSafe cmc安全交底
     * @return 结果
     */
    @Override
    public int updateCmcSafe(CmcSafe cmcSafe)
    {
        return cmcSafeMapper.updateCmcSafe(cmcSafe);
    }

    /**
     * 批量删除cmc安全交底
     * 
     * @param safeIds 需要删除的cmc安全交底主键
     * @return 结果
     */
    @Override
    public int deleteCmcSafeBySafeIds(String[] safeIds)
    {
        return cmcSafeMapper.deleteCmcSafeBySafeIds(safeIds);
    }

    /**
     * 删除cmc安全交底信息
     * 
     * @param safeId cmc安全交底主键
     * @return 结果
     */
    @Override
    public int deleteCmcSafeBySafeId(String safeId)
    {
        return cmcSafeMapper.deleteCmcSafeBySafeId(safeId);
    }
}
